**Example 1: 获取所有资源数量**



Input: 

```
tccli cwp DescribeAssetTotalCount --cli-unfold-argument ```

Output: 
```
{
    "Response": {
        "RequestId": "xx",
        "Types": [
            {
                "Value": 0,
                "Key": "xx",
                "Desc": "xx"
            }
        ]
    }
}
```

